ryuuseijin.consistent-hashing

A consistent hashing implementation using sorted-map as the core datastructure for amortized constant time lookups.

A consistent hashing implementation using sorted-map as the core datastructure for amortized constant time lookups.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries